/* global beforeEach, describe, it */
/* jshint maxlen: 200, maxstatements: 20 */
'use strict';

var assert = require('proclaim');

describe('GET /tasks/{id}/results/{id}', function () {

	describe('with valid and existing task ID', function () {

		describe('with valid and existing result ID', function () {

			describe('with no query', function () {

				beforeEach(function (done) {
					var req = {
						method: 'GET',
						endpoint: 'tasks/abc000000000000000000001/results/def000000000000000000001'
					};
					this.navigate(req, done);
				});

				it('should send a 200 status', function () {
					assert.strictEqual(this.last.status, 200);
				});

				it('should output a JSON representation of the requested result', function (done) {
					var body = this.last.body;
					this.app.model.result.getById('def000000000000000000001', false, function (err, result) {
						assert.isObject(body);
						assert.strictEqual(body.id, 'def000000000000000000001');
						assert.deepEqual(body, result);
						done();
					});
				});

			});

			describe('with full details query', function () {

				beforeEach(function (done) {
					var req = {
						method: 'GET',
						endpoint: 'tasks/abc000000000000000000001/results/def000000000000000000001',
						query: {
							full: true
						}
					};
					this.navigate(req, done);
				});

				it('should send a 200 status', function () {
					assert.strictEqual(this.last.status, 200);
				});

				it('should output a JSON representation of the requested result with full details', function (done) {
					var body = this.last.body;
					this.app.model.result.getById('def000000000000000000001', true, function (err, result) {
						assert.isObject(body);
						assert.strictEqual(body.id, 'def000000000000000000001');
						assert.deepEqual(body, result);
						done();
					});
				});

			});

			describe('with invalid query', function () {

				beforeEach(function (done) {
					var req = {
						method: 'GET',
						endpoint: 'tasks/abc000000000000000000001/results/def000000000000000000001',
						query: {
							foo: 'bar'
						}
					};
					this.navigate(req, done);
				});

				it('should send a 400 status', function () {
					assert.strictEqual(this.last.status, 400);
				});

			});

		});

		describe('with valid but non-existent result ID', function () {

			beforeEach(function (done) {
				var req = {
					method: 'GET',
					endpoint: 'tasks/abc000000000000000000001/results/def000000000000000000000'
				};
				this.navigate(req, done);
			});

			it('should send a 404 status', function () {
				assert.strictEqual(this.last.status, 404);
			});

		});

		describe('with invalid result ID', function () {

			beforeEach(function (done) {
				var req = {
					method: 'GET',
					endpoint: 'tasks/abc000000000000000000001/results/-def-'
				};
				this.navigate(req, done);
			});

			it('should send a 404 status', function () {
				assert.strictEqual(this.last.status, 404);
			});

		});

	});

	describe('with valid and existing but non-matching task ID', function () {

		beforeEach(function (done) {
			var req = {
				method: 'GET',
				endpoint: 'tasks/abc000000000000000000002/results/def000000000000000000001'
			};
			this.navigate(req, done);
		});

		it('should send a 404 status', function () {
			assert.strictEqual(this.last.status, 404);
		});

	});

	describe('with valid but non-existent task ID', function () {

		beforeEach(function (done) {
			var req = {
				method: 'GET',
				endpoint: 'tasks/abc000000000000000000000/results/def000000000000000000001'
			};
			this.navigate(req, done);
		});

		it('should send a 404 status', function () {
			assert.strictEqual(this.last.status, 404);
		});

	});

	describe('with invalid task ID', function () {

		beforeEach(function (done) {
			var req = {
				method: 'GET',
				endpoint: 'tasks/-abc-/results/def000000000000000000001'
			};
			this.navigate(req, done);
		});

		it('should send a 404 status', function () {
			assert.strictEqual(this.last.status, 404);
		});

	});

});
